..
      Copyright 2011-2012 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

=========================
Contributor Documentation
=========================

.. toctree::
   :maxdepth: 1

   how-can-i-help.rst
   set-up-keystone.rst
   http-api.rst
   proposing-features.rst
   release-notes.rst
   testing-keystone.rst
   doctor-checks.rst
   api_change_tutorial.rst
   auth-plugins.rst
   database-migrations.rst
   id-manage.rst
   translated-responses.rst
   architecture.rst
   services.rst
   developing-drivers.rst
   service-catalog.rst
   vision-reflection.rst
   programming-exercises.rst
